@@ -1,5 +1,4 @@
 from collections import defaultdict, deque
-from dataclasses import is_dataclass
 from random import choice
 from typing import TYPE_CHECKING, Any, Callable, Optional, Type, cast
 
@@ -18,8 +17,7 @@ from pydantic.fields import (
     ModelField,
 )
 
-from pydantic_factories.exceptions import ParameterError
-from pydantic_factories.utils import is_pydantic_model
+from pydantic_factories.utils import is_any, is_union
 from pydantic_factories.value_generators.primitives import create_random_string
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -53,20 +51,6 @@ shape_mapping = {
 }
 
 
-def is_union(model_field: ModelField) -> bool:
-    """Determines whether the given model_field is type Union"""
-    return repr(model_field.outer_type_).split("[")[0] == "typing.Union"
-
-
-def is_any(model_field: ModelField) -> bool:
-    """Determines whether the given model_field is type Any"""
-    return model_field.type_ is Any or (
-        hasattr(model_field.outer_type_, "_name")
-        and getattr(model_field.outer_type_, "_name")
-        and "Any" in getattr(model_field.outer_type_, "_name")
-    )
-
-
 def handle_container_type(model_field: ModelField, container_type: Callable, model_factory: Type["ModelFactory"]):
     """Handles generation of container types, e.g. dict, list etc. recursively"""
     is_frozen_set = False
@@ -92,9 +76,6 @@ def handle_container_type(model_field: ModelField, container_type: Callable, mod
 
 def handle_complex_type(model_field: ModelField, model_factory: Type["ModelFactory"]) -> Any:
     """Recursive type generation based on typing info stored in the graph like structure of pydantic model_fields"""
-
-    providers = model_factory.get_provider_map()
-    field_type = model_field.type_
     container_type: Optional[Callable] = shape_mapping.get(model_field.shape)
     if container_type:
         if container_type != tuple:
@@ -109,13 +90,6 @@ def handle_complex_type(model_field: ModelField, model_factory: Type["ModelFacto
         return handle_complex_type(model_field=choice(model_field.sub_fields), model_factory=model_factory)
     if is_any(model_field=model_field):
         return create_random_string(min_length=1, max_length=10)
-    if field_type in model_factory.get_provider_map():
-        return providers[field_type]()
-    if is_pydantic_model(field_type) or is_dataclass(field_type):
-        return model_factory.create_factory(model=field_type).build()
-    if model_factory.is_ignored_type(field_type):
+    if model_factory.should_set_none_value(model_field):
         return None
-    raise ParameterError(
-        f"Unsupported type: {repr(field_type)}"
-        f"\n\nEither extend the providers map or add a factory function for this model field"
-    )
+    return model_factory.get_field_value(model_field=model_field)
